#ifndef _WRAPI_H_
#define _WPAPI_H_

BOOL LoadWRAPI(void);

// Features (capabilities)

#define	RIF_USVERSION	0x00000001
#define RIF_DSP			0x00000002
#define RIF_LSBUSB		0x00000004

// WiNRADiO Hardware Versions 

#define VER_STANDARD	0x0100			// old, obsolete constants 
#define VER_STANDARD2	0x010a
#define VER_SPECMON		0x0200

#define RHV_1000		VER_STANDARD2	// new preferred version constants 
#define RHV_3000		VER_SPECMON

// Modes   ( bit 1 set = FM mode! (mode & RMD_FMN != 0) )

#define RMD_CW			0
#define RMD_AM			1
#define RMD_FMN			2
#define RMD_FMW			3
#define RMD_LSB			4
#define RMD_USB			5
	
// Mode Bandwidths 

#define RBW_DEFAULT		0
#define RBW_2500		0x0200  // Default for LSB/USB (and CW for WR-3000) 
#define RBW_6k			0x0300  // Default for AM (and SSB for WR-1000) 
#define RBW_17k			0x0500  // Default for FMN 
#define RBW_280k		0x0700	// Default for FMW 

// Hardware interfaces 

#define RHI_ISA			0

// 

typedef int FAR *LPMODELIST;

typedef struct tRADIOINFO
{
    DWORD       dwSize;				// size of structure (must be set before calling GetRadioDeviceInfo) 
    DWORD       dwFeatures;			// bit flags for extra features
    WORD        wAPIVer;			// driver version
    WORD        wHWVer;				// hardware version
    DWORD       dwMinFreq;			// minimum frequency receiver can tune to
    DWORD       dwMaxFreq;			// maximum frequency receiver can tune to 
    int         iFreqRes;			// resolution of receiver in Hz 
    int         iNumModes;			// number of modes that can be set 
    int         iMaxVolume;			// maximum volume level 
    int         iMaxBFO;			// maximum BFO offset range (+/- in Hz) 
    int         iMaxFMScanRate;		// maximum scan rate for FM scanning/sweeping
    int         iMaxAMScanRate;		// maximum scan rate for AM scanning/sweeping
    int         iHWInterface;		// physical interface radio is connected to 
	int			iDeviceNum;			// logical radio device number	
    int         iNumSources;        // number of selectable audio sources
    int         iMaxIFShift;        // maximum IF shift
    DWORD       dwWaveFormats;      // bit array of supported rec/play formats
    int			iDSPSources;		// number of selectable DSP input sources 
    LPMODELIST  lpSupportedModes;   // list of available modes
} RADIOINFO, *PRADIOINFO, FAR *LPRADIOINFO;

// API functions

int     (WINAPI *OpenRadioDevice)(int);
BOOL	(WINAPI *CloseRadioDevice)(int);

int		(WINAPI *GetRadioDeviceInfo)(int, LPRADIOINFO);
DWORD	(WINAPI *GetSignalStrength)(int);

BOOL	(WINAPI *SetFrequency)(int, DWORD);
BOOL	(WINAPI *SetMode)(int, int);
BOOL	(WINAPI *SetAtten)(int, BOOL);	
BOOL	(WINAPI *SetMute)(int, BOOL);
BOOL    (WINAPI *SetPower)(int, BOOL);
BOOL    (WINAPI *SetVolume)(int, int);
BOOL	(WINAPI *SetBFOOffset)(int, int);

DWORD	(WINAPI *GetFrequency)(int);
int		(WINAPI *GetMode)(int);
BOOL	(WINAPI *GetAtten)(int);
BOOL	(WINAPI *GetMute)(int);
BOOL    (WINAPI *GetPower)(int);
DWORD   (WINAPI *GetVolume)(int);
int		(WINAPI *GetBFOOffset)(int);

LPSTR	(WINAPI *GetModeString)(int, int, LPSTR, int);

#endif